==> dde-dock_5.4.7.orig.tar.xz: dde-dock-5.4.7/translations/dde-dock_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Lisäosa %1 ei ole yhteensopiva järjestelmän kanssa.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth asetukset</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Poista käytöstä</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Kytke käyttöön</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth asetukset</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 yhdistetty</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Yhdistetään...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Pois päältä</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Lisää näppäimistön asettelu</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Kello</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12h aika</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24h aika</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Aika-asetukset</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Kytke verkko käyttöön</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Poista verkko käytöstä</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Verkon asetukset</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Haluatko tyhjentää %1 kohdetta?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tätä toimintoa ei voi kumota</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Tuntematon laite</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Tuntematon asema</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Levy</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Irroita kaikki</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Käynnistin</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Alavalikko</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Piilotta paneeli</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Piilota automaattisesti</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Lisäosat</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Työtilan ikkunat</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Irrota</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Poista kiinteä yhteys</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kytke kiinteä yhteys</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Poista langaton käytöstä</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Kytke langaton käyttöön</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Poista verkko käytöstä</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Kytke verkko käyttöön</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Verkon asetukset</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Laite suljettu</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Langaton: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Verkkokaapeli: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ei yhteyttä</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Yhdistää</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Yhdistetty, mutta ei internet osoitetta</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Verkkokaapeli irrotettu</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kaapeli</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Yhteys epäonnistui</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kaapeli</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kaapeli %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Näppäimistö</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Asetukset virta</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Akku %1, %2 min jäljellä</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Akku %1, %2 t %3 min jäljellä</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Lataa %1, %2 min täyteen</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Lataa %1, %2 t %3 min täyteen</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Ladattu</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Varaus %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Ladataan: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Varaus %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Varaus %1, täyteen ladattu</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Näytä työpöytä</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Irrota</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lukitse</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Vaihda käyttäjää</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Asetukset virta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Laite</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ääntä</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Vaienna</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ääniasetukset</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Äänitaso: %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ääni</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Roskakori</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Roskakori - %1 tiedosto</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Roskakori - %1 tiedostoa</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Tyhjennä</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Ilmaisinalue</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Langaton verkko</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Langaton verkko: %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Lisäosa %1 ei ole yhteensopiva järjestelmän kanssa.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Lentotila</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Lentotila käytössä</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Poista käytöstä</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Kytke käyttöön</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Lentotilan asetukset</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Lentotila pois käytöstä</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Lentotila</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth asetukset</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Poista käytöstä</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Kytke käyttöön</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth asetukset</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 yhdistetty</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Yhdistetään...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Pois päältä</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Lisää näppäimistön asettelu</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Kello</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12h aika</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24h aika</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Aika-asetukset</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Maanantai</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Tiistai</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Keskiviikko</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Torstai</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Perjantai</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Lauantai</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sunnuntai</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>maanantai</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>tiistai</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>keskiviikko</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>torstai</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>perjantai</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>lauantai</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sunnuntai</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation>%3day%2month%1year</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Haluatko tyhjentää %1 kohdetta?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Tätä toimintoa ei voi kumota</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Tuntematon laite</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Tuntematon asema</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Levy</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Irroita kaikki</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Käynnistin</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Poistu vikasietotilasta</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Paneeli - vikasietotila</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Paneeli on vikasietotilassa. Poistu nähtyäsi sen toimivan oikein</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Alavalikko</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Piilotta paneeli</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Piilota automaattisesti</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Näytä</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Telakan asetukset</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Koko</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Useita näyttöjä</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Laajennusalue</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Valitse mitkä kuvakkeet näkyvät telakassa</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Muodikas </translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Tehokas</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tila</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Ylhäällä</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alhaalla</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Sijainti</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Näytä aina</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Pidä piilossa</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Älykäs piilotus</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Pieni</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Suuri</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Näytä telakka</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Näytöllä, jossa kohdistin on</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Vain päänäytöllä</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Työtilan ikkunat</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Näppäimistö</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Asetukset virta</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Akku %1, %2 min jäljellä</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Akku %1, %2 t %3 min jäljellä</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Lataa %1, %2 min täyteen</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Lataa %1, %2 t %3 min täyteen</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Varaus %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Ladataan: %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Varaus %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Varaus %1, täyteen ladattu</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Telakka</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Näytä telakka</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Laajennusalue</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Näytä työpöytä</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lukitse</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Vaihda käyttäjää</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Virta-asetukset</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Voimakkuus</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ääntä</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Vaienna</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ääniasetukset</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Voimakkuus: %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Ei ulostulon laitteita</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ääni</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Roskakori</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Roskakori - %1 tiedosto</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Roskakori - %1 tiedostoa</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Siirrä roskakoriin</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Tyhjennä</translation>
    </message>
</context>
</TS>
